[Debian-NP-Commits] r228 - people/vagrant/simple-cdd

Vagrant Cascadian debian-np-devel@lists.alioth.debian.org
Mon, 22 Nov 2004 17:31:56 -0700


Author: vagrant-guest
Date: Mon Nov 22 17:31:30 2004
New Revision: 228

Modified:
   people/vagrant/simple-cdd/CONF.sh
   people/vagrant/simple-cdd/build-simple-cdd
Log:
works with debian-installer rc2, which is in sarge now.


Modified: people/vagrant/simple-cdd/CONF.sh
==============================================================================
--- people/vagrant/simple-cdd/build-simple-cdd	(original)
+++ people/vagrant/simple-cdd/build-simple-cdd	Mon Nov 22 17:31:30 2004
@@ -75,11 +75,12 @@
   exit 1
 fi
 
-# FIXME workaround untill sarge debian-installer is viable.
-cd $MIRROR/dists
-echo "WARNING: using sid installer instead of sarge installer"
-mkdir -p sarge/main/installer-i386/current
-rsync --delete -aWHr sid/main/installer-i386/current/. sarge/main/installer-i386/current/
+if [ "true" = "$use_sid_installer" ]; then
+  cd $MIRROR/dists
+  echo "WARNING: using sid installer instead of sarge installer"
+  mkdir -p sarge/main/installer-i386/current
+  rsync --delete -aWHr sid/main/installer-i386/current/. sarge/main/installer-i386/current/
+fi
 
 cd $BASEDIR
--- people/vagrant/simple-cdd/CONF.sh	(original)
+++ people/vagrant/simple-cdd/CONF.sh	Mon Nov 22 17:31:30 2004
@@ -308,7 +308,7 @@
 export SIZELIMIT=739631360
 
 # these are generally debian-cd files which should get included
-includes="$BASEDIR/tasks/debian-installer+kernel $BASEDIR/tasks/debian-installer $BASEDIR/tasks/base-sarge"
+includes="$BASEDIR/tasks/debian-installer+kernel $BASEDIR/tasks/debian-installer $BASEDIR/tasks/base-$CODENAME"
 
 # files which contain lists of packages
 package_files="simple-cdd-packages.list"
@@ -318,9 +318,12 @@
 
 #export http_proxy=http://localhost:3128
 
+# use the sid installer
+use_sid_installer="false"
+
 # debpartial-mirror.conf files variable
-# TODO when sarge is ready, use $CODENAME instead of sid
-debpartial_files="README doc/ tools/ indices/ dists/sid/main/installer-i386/current/"
+# TODO if use_sid_installer is true, use sid instead
+debpartial_files="README doc/ tools/ indices/ dists/$CODENAME/main/installer-i386/current/"
 
 # debpartial-mirror server variable
 debpartial_debian_mirror="http://ftp.us.debian.org/debian/"

Modified: people/vagrant/simple-cdd/build-simple-cdd
==============================================================================